Learn R Programming

DamiaNN (version 1.0.0)

Start: start script

Description

main function that runs the interactive script

Usage

Start()

Arguments

Details

takes your numerai training data and trains a neural network to your architectural specifications. provides you with the out of sample error offers to retrain with a new architecture or predict on a numerai tournament dataset. Can then write the predictions to a CSV