Learn R Programming

DamiaNN (version 1.0.0)

Train,Neural_Network,data.frame,numeric,numeric,numeric-method: train the NN

Description

gets NN parameters that minimize cost on dataset using optimization_method

Usage

"Train"(object, dataset, regularization_constant, learning_rate, tolerable_error)

Arguments

object
is a Neural Network
dataset
is a data.frame, the original data frame that includes the target
regularization_constant
is a numeric
learning_rate
is a numeric
tolerable_error
is a numeric, units : log loss

Value

Neural_Network