back_propogation,Neural_Network,numeric,numeric,numeric-method: back prop
Description
updates connection strengths using results of last forward prop
Usage
"back_propogation"(object, target, regularization_parameter, learning_rate)
Arguments
object
is a Neural_Network
target
is a numeric vector
regularization_parameter
is non-negative number punishes strong connections
learning_rate
is a positive number that controls the rate at which connections are adjusted